![quansight_logo](source/images/qhub_logo.png)

[![Python version](https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9%20%7C%203.10-blue.svg)](https://pypi.org/project/qhub/)
[![PyPI version](https://badge.fury.io/py/qhub.svg)](https://badge.fury.io/py/qhub)
[![Conda version](https://img.shields.io/badge/conda--forge-v0.3.0-%234f28a8)](https://anaconda.org/conda-forge/qhub)
[![GitHub issues](https://img.shields.io/github/issues/quansight/qhub?style=plastic)](https://github.com/Quansight/qhub/issues/new/choose)

Open source tooling for data science research, development, and deployment.

# What is QHub?

QHUb is an integrated data science environment designed and developed by scientists at
[**Quansight**](https://www.quansight.com/). It enables teams to build and maintain a cost effective and scalable
compute/data science platform in the Cloud, providing an
[**Infrastructure as Code**](https://en.wikipedia.org/wiki/Infrastructure_as_code) platform that streamlines the
deployment of data science infrastructure.

```{toctree}
:maxdepth: 1
source/introduction/index.md
source/installation/index.md
source/user_guide/index.md
source/admin_guide/index.md
source/dev_guide/index.md
```
